@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.caching.internal;
 
+import java.io.InputStream;
 import java.io.Serializable;
 import org.apache.jcs.JCS;
 import com.openexchange.caching.Cache;
@@ -120,6 +121,10 @@ public final class JCSCacheService implements CacheService {
         JCSCacheServiceInit.getInstance().loadConfiguration(cacheConfigFile);
     }
 
+    public void loadConfiguration(final InputStream inputStream) throws CacheException {
+        JCSCacheServiceInit.getInstance().loadConfiguration(inputStream);
+    }
+
     public void loadDefaultConfiguration() throws CacheException {
         JCSCacheServiceInit.getInstance().loadDefaultConfiguration();
     }
